@@ -1,6 +1,6 @@
 package Bio::MLST::FilterAlleles;
 # ABSTRACT: Filter Alleles
-$Bio::MLST::FilterAlleles::VERSION = '2.1.1630714';
+$Bio::MLST::FilterAlleles::VERSION = '2.1.1630715';
 
 use strict;
 use warnings;
@@ -26,7 +26,14 @@ my @allele_blacklist = (
 sub is_metadata
 {
   my ($column_heading) = @_;
-  return grep( /^$column_heading$/, @allele_blacklist );
+  if(defined($column_heading))
+  {
+     return grep( /^$column_heading$/, @allele_blacklist );
+  }
+  else
+  {
+     return 0;
+  }
 }
 
 sub only_keep_alleles
@@ -53,7 +60,7 @@ Bio::MLST::FilterAlleles - Filter Alleles
 
 =head1 VERSION
 
-version 2.1.1630714
+version 2.1.1630715
 
 =head1 SYNOPSIS
 
